@@ -10,7 +10,7 @@ from tornado import web, ioloop, httpserver
 from tornado.template import Loader
 
 from .sql import SQLX
-from ..configuration import PlotmanConfig, get_dash_v1, get_dash_v1_static
+from ..configuration import PlotmanConfig, get_dash_v1,get_dash_v1_static
 
 __author__ = 'lousvicton'
 
@@ -157,6 +157,80 @@ class WebpHandler(web.StaticFileHandler):
                 super().write_error(status_code, **kwargs)
 
 
+# Reset
+Color_Off = '\033[0m'  # Text Reset
+
+# Regular Colors
+Black = '\033[0;30m'  # Black
+Red = '\033[0;31m'  # Red
+Green = '\033[0;32m'  # Green
+Yellow = '\033[0;33m'  # Yellow
+Blue = '\033[0;34m'  # Blue
+Purple = '\033[0;35m'  # Purple
+Cyan = '\033[0;36m'  # Cyan
+White = '\033[0;37m'  # White
+
+# Bold
+BBlack = '\033[1;30m'  # Black
+BRed = '\033[1;31m'  # Red
+BGreen = '\033[1;32m'  # Green
+BYellow = '\033[1;33m'  # Yellow
+BBlue = '\033[1;34m'  # Blue
+BPurple = '\033[1;35m'  # Purple
+BCyan = '\033[1;36m'  # Cyan
+BWhite = '\033[1;37m'  # White
+
+# Underline
+UBlack = '\033[4;30m'  # Black
+URed = '\033[4;31m'  # Red
+UGreen = '\033[4;32m'  # Green
+UYellow = '\033[4;33m'  # Yellow
+UBlue = '\033[4;34m'  # Blue
+UPurple = '\033[4;35m'  # Purple
+UCyan = '\033[4;36m'  # Cyan
+UWhite = '\033[4;37m'  # White
+
+# Background
+On_Black = '\033[40m'  # Black
+On_Red = '\033[41m'  # Red
+On_Green = '\033[42m'  # Green
+On_Yellow = '\033[43m'  # Yellow
+On_Blue = '\033[44m'  # Blue
+On_Purple = '\033[45m'  # Purple
+On_Cyan = '\033[46m'  # Cyan
+On_White = '\033[47m'  # White
+
+# High Intensity
+IBlack = '\033[0;90m'  # Black
+IRed = '\033[0;91m'  # Red
+IGreen = '\033[0;92m'  # Green
+IYellow = '\033[0;93m'  # Yellow
+IBlue = '\033[0;94m'  # Blue
+IPurple = '\033[0;95m'  # Purple
+ICyan = '\033[0;96m'  # Cyan
+IWhite = '\033[0;97m'  # White
+
+# Bold High Intensity
+BIBlack = '\033[1;90m'  # Black
+BIRed = '\033[1;91m'  # Red
+BIGreen = '\033[1;92m'  # Green
+BIYellow = '\033[1;93m'  # Yellow
+BIBlue = '\033[1;94m'  # Blue
+BIPurple = '\033[1;95m'  # Purple
+BICyan = '\033[1;96m'  # Cyan
+BIWhite = '\033[1;97m'  # White
+
+# High Intensity backgrounds
+On_IBlack = '\033[0;100m'  # Black
+On_IRed = '\033[0;101m'  # Red
+On_IGreen = '\033[0;102m'  # Green
+On_IYellow = '\033[0;103m'  # Yellow
+On_IBlue = '\033[0;104m'  # Blue
+On_IPurple = '\033[0;105m'  # Purple
+On_ICyan = '\033[0;106m'  # Cyan
+On_IWhite = '\033[0;107m'  # White
+
+
 def start_master_api_node(cfg: PlotmanConfig):
     try:
         version = pkg_resources.get_distribution('plotmanx').version
@@ -166,10 +240,13 @@ def start_master_api_node(cfg: PlotmanConfig):
         settings = dict(
             debug=True,
             gzip=True,
-            template_path=get_dash_v1(),
-            static_path=get_dash_v1_static(),
+            static_path=get_dash_v1(),
         )
 
+        """
+      template_path=get_dash_v1(),
+            static_path=get_dash_v1_static(),
+            """
         static_handler_args = dict(
             path=get_dash_v1(),
             default_filename="index.html"
@@ -183,12 +260,12 @@ def start_master_api_node(cfg: PlotmanConfig):
         ], **settings)
 
         print(f"Serve nuxt path {get_dash_v1()} and set default entry point as index.html")
-        print('Running at: http://%s:%s/', '127.0.0.1', cfg.apis.port)
+        print(f"Running at:{BCyan} http://{'127.0.0.1'}:{cfg.apis.port}/ {Color_Off}")
         http_server = httpserver.HTTPServer(appcli)
         http_server.listen(cfg.apis.port)
         ioloop.IOLoop.current().start()
 
-    except ValueError:
-        print("Port is in use. Please close the daemon app and start again. ")
+    except OSError:
+        print(f"{BRed}Port is in use.{Color_Off} Please close the daemon app and start again. ")
     except KeyboardInterrupt:
         print('Stopping server...')
